@@ -17,6 +17,7 @@
 
 from typing import Dict
 
+from appium.options.common.automation_name_option import AUTOMATION_NAME
 from appium.options.common.base import AppiumOptions
 
 
@@ -26,5 +27,5 @@ class GeckoOptions(
     @property
     def default_capabilities(self) -> Dict:
         return {
-            AppiumOptions.AUTOMATION_NAME: 'Gecko',
+            AUTOMATION_NAME: 'Gecko',
         }
