@@ -13,10 +13,11 @@
 # limitations under the License.
 
 import os
+import re
 import subprocess as sp
 import sys
 import time
-from typing import Any, List, Optional, TypeVar, Union
+from typing import Any, List, Optional, Union
 
 import urllib3
 
@@ -24,13 +25,14 @@ DEFAULT_HOST = '127.0.0.1'
 DEFAULT_PORT = 4723
 STARTUP_TIMEOUT_MS = 60000
 MAIN_SCRIPT_PATH = 'appium/build/lib/main.js'
-STATUS_URL = '/wd/hub/status'
+STATUS_URL = '/status'
+DEFAULT_BASE_PATH = '/'
 
 
 def find_executable(executable: str) -> Optional[str]:
     path = os.environ['PATH']
     paths = path.split(os.pathsep)
-    base, ext = os.path.splitext(executable)
+    _, ext = os.path.splitext(executable)
     if sys.platform == 'win32' and not ext:
         executable = executable + '.exe'
 
@@ -47,13 +49,13 @@ def find_executable(executable: str) -> Optional[str]:
 
 def poll_url(host: str, port: int, path: str, timeout_ms: int) -> bool:
     time_started_sec = time.time()
+    conn = urllib3.PoolManager(timeout=1.0)
     while time.time() < time_started_sec + timeout_ms / 1000.0:
         try:
-            conn = urllib3.PoolManager(timeout=1.0)
             resp = conn.request('HEAD', f'http://{host}:{port}{path}')
             if resp.status < 400:
                 return True
-        except Exception:
+        except urllib3.exceptions.HTTPError:
             pass
         time.sleep(1.0)
     return False
@@ -72,16 +74,18 @@ class AppiumService:
         if not hasattr(self, '_node_executable'):
             self._node_executable = find_executable('node')
         if self._node_executable is None:
-            raise AppiumServiceError('NodeJS main executable cannot be found. ' +
-                                     'Make sure it is installed and present in PATH')
+            raise AppiumServiceError(
+                'NodeJS main executable cannot be found. ' + 'Make sure it is installed and present in PATH'
+            )
         return self._node_executable
 
     def _get_npm(self) -> str:
         if not hasattr(self, '_npm_executable'):
             self._npm_executable = find_executable('npm.cmd' if sys.platform == 'win32' else 'npm')
         if self._npm_executable is None:
-            raise AppiumServiceError('Node Package Manager executable cannot be found. ' +
-                                     'Make sure it is installed and present in PATH')
+            raise AppiumServiceError(
+                'Node Package Manager executable cannot be found. ' + 'Make sure it is installed and present in PATH'
+            )
         return self._npm_executable
 
     def _get_main_script(self) -> Union[str, bytes]:
@@ -97,9 +101,8 @@ class AppiumService:
             if not hasattr(self, '_main_script'):
                 try:
                     self._main_script = sp.check_output(
-                        [self._get_node(),
-                         '-e',
-                         'console.log(require.resolve("{}"))'.format(MAIN_SCRIPT_PATH)]).strip()
+                        [self._get_node(), '-e', f'console.log(require.resolve("{MAIN_SCRIPT_PATH}"))']
+                    ).strip()
                 except sp.CalledProcessError as e:
                     raise AppiumServiceError(e.output) from e
         return self._main_script
@@ -111,6 +114,13 @@ class AppiumService:
                 return int(args[idx + 1])
         return DEFAULT_PORT
 
+    @staticmethod
+    def _parse_base_path(args: List[str]) -> str:
+        for idx, arg in enumerate(args or []):
+            if arg in ('--base-path', '-pa') and idx < len(args) - 1:
+                return args[idx + 1]
+        return DEFAULT_BASE_PATH
+
     @staticmethod
     def _parse_host(args: List[str]) -> str:
         for idx, arg in enumerate(args or []):
@@ -125,33 +135,36 @@ class AppiumService:
 
         Keyword Args:
             env (dict): Environment variables mapping. The default system environment,
-                which is inherited from the parent process is assigned by default.
+                which is inherited from the parent process, is assigned by default.
             node (str): The full path to the main NodeJS executable. The service will try
                 to retrieve it automatically by default.
-            stdout (int): Check on the documentation for subprocess.Popen for more details.
-                The default value is subprocess.PIPE.
-            stderr (int): Check on the documentation for subprocess.Popen for more details.
-                The default value is subprocess.PIPE.
+            stdout (int): Check the documentation for subprocess.Popen for more details.
+                The default value is subprocess.DEVNULL on Windows and subprocess.PIPE on other platforms.
+            stderr (int): Check the documentation for subprocess.Popen for more details.
+                The default value is subprocess.DEVNULL on Windows and subprocess.PIPE on other platforms.
             timeout_ms (int): The maximum time to wait until Appium process starts listening
                 for HTTP connections. If set to zero or a negative number then no wait will be applied.
-                60000 ms by default
+                60000 ms by default.
             main_script (str): The full path to the main Appium executable
-                (usually located this is build/lib/main.js). If this is not set
+                (usually located at build/lib/main.js). If this is not set
                 then the service tries to detect the path automatically.
-            args (str): List of Appium arguments (all must be strings). Check on
+            args (str): List of Appium arguments (all must be strings). Check
                 https://appium.io/docs/en/writing-running-appium/server-args/ for more details
                 about possible arguments and their values.
 
         Returns:
             You can use Popen.communicate interface or stderr/stdout properties
-            of the instance (stdout/stderr must not be set to None in such case) in order to retrieve the actual process output.
+            of the instance (stdout/stderr must not be set to None in such case) in order to retrieve the actual process
+            output.
         """
         self.stop()
 
         env = kwargs['env'] if 'env' in kwargs else None
         node = kwargs['node'] if 'node' in kwargs else self._get_node()
-        stdout = kwargs['stdout'] if 'stdout' in kwargs else sp.PIPE
-        stderr = kwargs['stderr'] if 'stderr' in kwargs else sp.PIPE
+        # A workaround for https://github.com/appium/python-client/issues/534
+        default_std = sp.DEVNULL if sys.platform == 'win32' else sp.PIPE
+        stdout = kwargs['stdout'] if 'stdout' in kwargs else default_std
+        stderr = kwargs['stderr'] if 'stderr' in kwargs else default_std
         timeout_ms = int(kwargs['timeout_ms']) if 'timeout_ms' in kwargs else STARTUP_TIMEOUT_MS
         main_script = kwargs['main_script'] if 'main_script' in kwargs else self._get_main_script()
         args = [node, main_script]
@@ -162,7 +175,11 @@ class AppiumService:
         host = self._parse_host(args)
         port = self._parse_port(args)
         error_msg: Optional[str] = None
-        if not self.is_running or (timeout_ms > 0 and not poll_url(host, port, STATUS_URL, timeout_ms)):
+        base_path = self._parse_base_path(args)
+        status_url_path = (
+            STATUS_URL if base_path == DEFAULT_BASE_PATH else f'{re.sub(r"[/]+$", "", base_path)}{STATUS_URL}'
+        )
+        if not self.is_running or (timeout_ms > 0 and not poll_url(host, port, status_url_path, timeout_ms)):
             error_msg = f'Appium has failed to start on {host}:{port} within {timeout_ms}ms timeout'
         if error_msg is not None:
             if stderr == sp.PIPE and self._process.stderr is not None:
@@ -214,17 +231,21 @@ class AppiumService:
             return False
         host = self._parse_host(self._cmd)
         port = self._parse_port(self._cmd)
-        return self.is_running and poll_url(host, port, STATUS_URL, 1000)
+        base_path = self._parse_base_path(self._cmd)
+        status_url_path = (
+            STATUS_URL if base_path == DEFAULT_BASE_PATH else f'{re.sub(r"[/]+$", "", base_path)}{STATUS_URL}'
+        )
+        return self.is_running and poll_url(host, port, status_url_path, 1000)
 
 
 if __name__ == '__main__':
-    assert(find_executable('node') is not None)
-    assert(find_executable('npm') is not None)
+    assert find_executable('node') is not None
+    assert find_executable('npm') is not None
     service = AppiumService()
     service.start(args=['--address', '127.0.0.1', '-p', str(DEFAULT_PORT)])
     # service.start(args=['--address', '127.0.0.1', '-p', '80'], timeout_ms=2000)
-    assert(service.is_running)
-    assert(service.is_listening)
+    assert service.is_running
+    assert service.is_listening
     service.stop()
-    assert(not service.is_running)
-    assert(not service.is_listening)
+    assert not service.is_running
+    assert not service.is_listening
