@@ -17,7 +17,7 @@
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 from selenium import webdriver
-from selenium.common.exceptions import InvalidArgumentException, WebDriverException
+from selenium.common.exceptions import InvalidArgumentException, SessionNotCreatedException, WebDriverException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.remote.command import Command as RemoteCommand
 from selenium.webdriver.remote.remote_connection import RemoteConnection
@@ -317,10 +317,25 @@ class WebDriver(
 
         w3c_caps = AppiumOptions.as_w3c(capabilities) if isinstance(capabilities, dict) else capabilities.to_w3c()
         response = self.execute(RemoteCommand.NEW_SESSION, w3c_caps)
-        if 'sessionId' not in response:
-            response = response['value']
-        self.session_id = response['sessionId']
-        self.caps = response.get('value') or response.get('capabilities')
+        # https://w3c.github.io/webdriver/#new-session
+        if not isinstance(response, dict):
+            raise SessionNotCreatedException(
+                f'A valid W3C session creation response must be a dictionary. Got "{response}" instead'
+            )
+        # Due to a W3C spec parsing misconception some servers
+        # pack the createSession response stuff into 'value' dictionary and
+        # some other put it to the top level of the response JSON nesting hierarchy
+        get_response_value: Callable[[str], Optional[Any]] = lambda key: response.get(key) or (
+            response['value'].get(key) if isinstance(response.get('value'), dict) else None
+        )
+        session_id = get_response_value('sessionId')
+        if not session_id:
+            raise SessionNotCreatedException(
+                f'A valid W3C session creation response must contain a non-empty "sessionId" entry. '
+                f'Got "{response}" instead'
+            )
+        self.session_id = session_id
+        self.caps = get_response_value('capabilities') or {}
 
     def find_element(self, by: str = AppiumBy.ID, value: Union[str, Dict] = None) -> MobileWebElement:
         """
@@ -337,7 +352,9 @@ class WebDriver(
             `appium.webdriver.webelement.WebElement`: The found element
 
         """
-        # TODO: If we need, we should enable below converter for Web context
+        # We prefer to patch locators in the client code
+        # Checking current context every time a locator is accessed could significantly slow down tests
+        # Check https://github.com/appium/python-client/pull/724 before submitting any issue
         # if by == By.ID:
         #     by = By.CSS_SELECTOR
         #     value = '[id="%s"]' % value
@@ -368,7 +385,9 @@ class WebDriver(
         Returns:
             :obj:`list` of :obj:`appium.webdriver.webelement.WebElement`: The found elements
         """
-        # TODO: If we need, we should enable below converter for Web context
+        # We prefer to patch locators in the client code
+        # Checking current context every time a locator is accessed could significantly slow down tests
+        # Check https://github.com/appium/python-client/pull/724 before submitting any issue
         # if by == By.ID:
         #     by = By.CSS_SELECTOR
         #     value = '[id="%s"]' % value
